summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Modules/FindDoxygen.cmake13
1 files changed, 12 insertions, 1 deletions
diff --git a/Modules/FindDoxygen.cmake b/Modules/FindDoxygen.cmake
index 506255a..586a934 100644
--- a/Modules/FindDoxygen.cmake
+++ b/Modules/FindDoxygen.cmake
@@ -1,7 +1,18 @@
#
# this module looks for Doxygen
#
FIND_PROGRAM(DOXYGEN
doxygen
)
+
+FIND_PROGRAM(DOT
+ dot
+ "C:/Program Files/ATT/Graphviz/bin"
+)
+# HKEY_CURRENT_USER\Software\AT&T\Graphviz
+
+# Since most of the time dot is called by Doxygen, the path to dot is useful too
+GET_FILENAME_COMPONENT(DOT_PATH ${DOT} PATH CACHE)
+
+
@@ -1,7 +1,18 @@
#
-# this module looks for Doxygen
+# this module looks for Doxygen and the path to Graphiz's dot
#
FIND_PROGRAM(DOXYGEN